<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://taamul.com
 * @since      1.0.2
 *
 * @package    Taamul
 * @subpackage Taamul/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Taamul
 * @subpackage Taamul/admin
 * @author     Taamul <taamul.inc@gmail.com>
 */
class Taamul_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.2
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.2
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.2
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.2
	 */
	public function enqueue_styles( $hook ) {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Taamul_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Taamul_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		if ( 'toplevel_page_taamul' === $hook  ) {
			wp_enqueue_style( 'taamul-reset', plugin_dir_url( __FILE__ ) . 'css/reset.css', array(), $this->version, 'all' );
			wp_enqueue_style( 'taamul-common', plugin_dir_url( __FILE__ ) . 'css/taamul-common.css', array(), $this->version, 'all' );
			wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/taamul-admin.css', array(), $this->version, 'all' );
		}

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.2
	 */
	public function enqueue_scripts( $hook ) {
		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Taamul_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Taamul_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		if ( 'toplevel_page_taamul' === $hook  ) {
			wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/taamul-admin.js', array( 'jquery' ), $this->version, false );
			
		}

	}
	
	/**
	 * Register Taamul Menu
	 */
	public function add_menu_page_taamul() {
        
		add_menu_page(
			__( 'Taamul Feedback', 'taamul' ), //page title
			__( 'Taamul Feedback', 'taamul' ), //menu title
			'manage_options', //capabilities
			'taamul', //menu slug
			array( $this, 'taamul_admin_pages' ), //function
			'data:image/svg+xml;base64,' . base64_encode('<svg width="18" height="16" fill="#f0f0f1" viewBox="0 0 18 16" xmlns="http://www.w3.org/2000/svg">
			<path d="M8.70479 0C3.93199 0 0 3.63524 0 8.03709C0 9.94127 0.717156 11.7465 2.02782 13.1808L0.197836 14.8624C0 15.0355 -0.049459 15.3323 0.049459 15.5796C0.148377 15.8269 0.395672 16 0.667697 16H8.70479C13.4776 16 17.3601 12.4142 17.3601 8.01237C17.3601 3.61051 13.4529 0 8.70479 0ZM11.4992 4.08037C12.1175 4.08037 12.6368 4.57496 12.6368 5.21793C12.6368 5.83617 12.1422 6.35549 11.4992 6.35549C10.881 6.35549 10.3617 5.8609 10.3617 5.21793C10.3617 4.57496 10.8563 4.08037 11.4992 4.08037ZM5.8609 4.08037C6.47913 4.08037 6.99845 4.57496 6.99845 5.21793C6.99845 5.83617 6.50386 6.35549 5.8609 6.35549C5.24266 6.35549 4.72334 5.8609 4.72334 5.21793C4.72334 4.57496 5.24266 4.08037 5.8609 4.08037ZM13.0077 9.12519C12.7357 10.7821 10.51 11.9444 8.68006 11.9444C6.85008 11.9444 4.62442 10.7821 4.3524 9.12519C4.30294 8.77898 4.62442 8.48223 4.97063 8.58114C5.88563 8.8779 7.24575 9.051 8.68006 9.051C10.1144 9.051 11.4745 8.8779 12.3895 8.58114C12.7357 8.48223 13.0572 8.77898 13.0077 9.12519Z" />
			</svg>'),
			'30'
		);

		global $submenu;	
		$submenu['taamul'][] = array( __( 'Dashboard', 'taamul' ), 'manage_options', admin_url( 'admin.php?page=taamul&tab=overview' ) );
		$submenu['taamul'][] = array( __( 'Report', 'taamul' ), 'manage_options', admin_url( 'admin.php?page=taamul&tab=report' ) );
		$submenu['taamul'][] = array( __( 'Appearance', 'taamul' ), 'manage_options', admin_url( 'admin.php?page=taamul&tab=appearance' ) );
		$submenu['taamul'][] = array( __( 'Notifications', 'taamul' ), 'manage_options', admin_url( 'admin.php?page=taamul&tab=notifications' ) );
		$submenu['taamul'][] = array( __( 'Settings', 'taamul' ), 'manage_options', admin_url( 'admin.php?page=taamul&tab=settings' ) );
		$submenu['taamul'][] = array( __( 'Support', 'taamul' ), 'manage_options', admin_url( 'admin.php?page=taamul&tab=support' ) );

    }

	/**
	 * Display Admin page.
	 */
	public function taamul_admin_pages(){
		include_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/taamul-admin-display.php';	
	}

	/**
	 * Hide all wordpress Notice
	 */
	public function taamul_hide_all_notice(){
		if( !empty( $_GET['page'] ) && sanitize_text_field( wp_unslash( $_GET['page'] ) ) == 'taamul' ){
			remove_all_actions('admin_notices');
		}
	}

	/**
	 * Tab Submenu got selected.
	 *
	 * @since 1.2
	 * @return void
	 */
	public function get_selected_tab_submenu( $submenu_file ){
		if( !empty( $_GET['page'] ) && sanitize_text_field( wp_unslash( $_GET['page'] ) ) == 'taamul' ){
			$allowed_tabs = array( 'overview', 'report', 'appearance', 'notifications', 'settings', 'support' );
			$tab = isset( $_GET['tab'] ) ? sanitize_text_field( $_GET['tab'] ) : 'overview';
			if( in_array( $tab, $allowed_tabs ) ){
				$submenu_file = admin_url( 'admin.php?page=taamul&tab='.$tab );
			}
		}
		return $submenu_file;
	}

	/**
     * Submit Taamul Appearance setting form validation
     *
     * @return void
     */
    public function taamul_appearance_form_handle(){
        global $taamul_success_msg, $taamul_errors_msg;
        if ( isset( $_POST['taamul_action'] ) && 'taamul_save_settings' === sanitize_text_field( wp_unslash( $_POST['taamul_action'] ) ) && check_admin_referer( 'taamul_setting_form_nonce_action', 'taamul_setting_form_nonce' ) ) { // input var okay.
           
			$appearance_options = isset( $_POST['appearance'] ) ? array_map( 'sanitize_text_field', wp_unslash( $_POST['appearance'] ) ) : array();

            $is_update = update_option( 'taamul_appearance_style', $appearance_options );
			if ( $is_update ) {
				$taamul_success_msg[] = __( 'Appearance settings has been saved successfully.', 'taamul' );
			} else {
				$taamul_errors_msg[] = __( 'Something went wrong! please try again.', 'taamul' );
			}
        
        }
    }

	/**
     * Submit Taamul Appearance setting form validation
     *
     * @return void
     */
    public function taamul_settings_form_handle(){
        global $taamul_success_msg, $taamul_errors_msg;

        if ( isset( $_POST['taamul_settings_action'] ) && 'taamul_save_settings' === sanitize_text_field( wp_unslash( $_POST['taamul_settings_action'] ) ) && check_admin_referer( 'taamul_settings_form_nonce_action', 'taamul_settings_form_nonce' ) ) { // input var okay.
           
			$settings_options = isset( $_POST['settings'] ) ? array_map( 'sanitize_text_field', wp_unslash( $_POST['settings'] ) ) : array();

			$is_update = update_option( 'taamul_settings_style', $settings_options );
			if ( $is_update ) {
				$taamul_success_msg[] = __( 'Settings has been saved successfully.', 'taamul' );
			} else {
				$taamul_errors_msg[] = __( 'Something went wrong! please try again.', 'taamul' );
			}
        
        }
    }


	public function taamul_handle_export() {
		global $taamul_success_msg, $taamul_errors_msg;

		if ( isset( $_GET['feedback_export_action'] ) && $_GET['feedback_export_action'] === 'export_all_csv_feedback' && isset( $_GET['_wpnonce'] ) && wp_verify_nonce( $_GET['_wpnonce'], 'export_all_feedback_csv_nonce' ) ) {
			if ( !empty( $_GET['export_feedback_data'] ) ) {
				if ( !empty( $_GET['export_feedback_type'] ) ) {
					$export_file = new Taamul_Feedback_Export();
					$export_feedback_type = sanitize_key( $_GET['export_feedback_type'] );
	
					if ( 'csv' === $export_feedback_type ) {
						$export_file->download( 'csv' );
					}
				}
			}
			if ( $is_update ) {
				$taamul_success_msg[] = __( 'Export CSV file successfully.', 'taamul' );
			} else {
				$taamul_errors_msg[] = __( 'Something went wrong! please try again.', 'taamul' );
			}
			wp_redirect( admin_url( 'admin.php?page=taamul&tab=report' ) );
			exit;
		}

		if ( isset( $_GET['feedback_export_action'] ) && $_GET['feedback_export_action'] === 'export_all_json_feedback' && isset( $_GET['_wpnonce'] ) && wp_verify_nonce( $_GET['_wpnonce'], 'export_all_feedback_json_nonce' ) ) {
			if ( !empty( $_GET['export_feedback_data'] ) ) {
				if ( !empty( $_GET['export_feedback_type'] ) ) {
					$export_file = new Taamul_Feedback_Export();
					$export_feedback_type = sanitize_key( $_GET['export_feedback_type'] );

				if ( 'json' === $export_feedback_type ) {
					$export_file->download( 'json' );
					}
				}
			}
			if ( $is_update ) {
				$taamul_success_msg[] = __( 'Export JSON file successfully.', 'taamul' );
			} else {
				$taamul_errors_msg[] = __( 'Something went wrong! please try again.', 'taamul' );
			}
			wp_redirect( admin_url( 'admin.php?page=taamul&tab=report' ) );
			exit;
		}

	}

	public function reset_feedback_setting() {
		global $taamul_success_msg, $taamul_errors_msg;

		$appearance_reset   = isset( $_GET['appearance_reset'] ) ? $_GET['appearance_reset'] : '';
		$notification_reset = isset( $_GET['notification_reset'] ) ? $_GET['notification_reset'] : '';

		if( $appearance_reset == 'true' ){
			$taamul_appearance_style = array(
				'position_on_page' 	=> 'middlerightwithtext',
				'reactions_style' 	=> 'emoji1',
				'desktops' 			=> 'on',
				'tablets' 			=> 'on',
				'phones' 			=> 'on',
				'feedback_title' 	=> 'Give us Your Feedback',
				'message_form' 		=> 'Tell us about your experience...',
				'thank_you_message' => 'Thank you for your awesome review',
				'send_button' 		=> 'Send',
				'message' 			=> 'on',
				'message_required' 	=> 'on',
				'show_email' 		=> 'on',
				'email_required' 	=> 'on'
			);
			$is_update = update_option( 'taamul_appearance_style', $taamul_appearance_style );

			if ( $is_update ) {
				$taamul_success_msg[] = __( 'Appearance settings has been reset successfully.', 'taamul' );
			} else {
				$taamul_success_msg[] = __( 'Appearance settings has been reset successfully.', 'taamul' );
			}

		}elseif( $notification_reset == 'true' ){

			$admin_email = get_option( 'admin_email', true );
			$taamul_notification_style = array(
				'email_recipient'   => $admin_email,
				'email_subject'     => 'New feedback submitted at'.get_bloginfo( 'name' ),
				'email_message'     => 'A new feedback has been submitted. View it: %link%. This email was sent from your website by the %plugin% plugin at %time%.',
			);
			$is_update = update_option( 'taamul_notification_setting', $taamul_notification_style );

			if ( $is_update ) {
				$taamul_success_msg[] = __( 'Notofication settings has been reset successfully.', 'taamul' );
			} else {
				$taamul_success_msg[] = __( 'Notofication settings has been reset successfully.', 'taamul' );
			}
		}
	}

	/**
     * Submit Taamul Notification setting form validation
     *
     * @return void
     */
    public function taamul_notification_form_handle(){
        global $taamul_success_msg, $taamul_errors_msg;

		if ( isset( $_POST['taamul_notification_action'] ) && 'taamul_notification_save_settings' === sanitize_text_field( wp_unslash( $_POST['taamul_notification_action'] ) ) && check_admin_referer( 'taamul_setting_form_notification_nonce_action', 'taamul_setting_form_notification_nonce' ) ) { // input var okay.
            
			$notification_options   = isset( $_POST['notification'] ) ? array_map( 'sanitize_text_field', wp_unslash( $_POST['notification'] ) ) : array();
			$notification_options['email_message'] = isset( $_POST['notification'] ) ? wp_kses_post( ( $_POST['notification']['email_message'] ) ) : '';
            $is_update = update_option( 'taamul_notification_setting', $notification_options );
			if ( $is_update ) {
				$taamul_success_msg[] = __( 'Notofication settings has been saved successfully.', 'taamul' );
			} else {
				$taamul_success_msg[] = __( 'Notofication settings has been saved successfully.', 'taamul' );
			}
        
        }
    }

	/**
     * Taamul display Admin notices
     *
     * @return void
     */
    public function admin_notices(){
        global $taamul_success_msg, $taamul_errors_msg;
		if ( ! empty( $taamul_success_msg ) ) {
			foreach ( $taamul_success_msg as $success ) :
				?>
				<div class="notice notice-success is-dismissible">
					<p><?php echo $success; ?></p>
				</div>
				<?php
			endforeach;
		}

		if ( ! empty( $taamul_errors_msg ) ) {
			foreach ( $taamul_errors_msg as $error ) :
				?>
				<div class="notice notice-error is-dismissible">
					<p><?php echo $error; ?></p>
				</div>
				<?php
			endforeach;
		}
    }
}
