<?php
if (!class_exists('WP_List_Table')) {
    require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}

class Taamul_Feed_List_Table extends WP_List_Table {

        function __construct(){
            global $status, $page;
    
            parent::__construct( array(
                'singular' => 'taamul',
                'plural'   => 'taamul',
            ) );			
        }
    
        function column_default( $item, $column_name ){
            return $item[$column_name];
        }
    
        function column_id( $item ){
            $actions = array(
                'delete' => sprintf('<a href="?page=taamul&tab=report&action=delete&id=%s" onclick="return confirm(\'Warning!! Are you sure to Delete this Feedback? Feedback will be permanatly deleted.\')">Delete</a>', $item['id'], __('Delete', 'taamul')),
            );
    
            return sprintf( '%s %s',
                $item['id'],
                $this->row_actions( $actions )
            );
        }
    
        function column_cb( $item ) {
            return sprintf(
                '<input type="checkbox" name="id[]" value="%s" />',
                $item['id']
            );
        }
    
  
        
        function get_columns(){
            $columns = array(
                'cb'            => '<input type="checkbox" />', //Render a checkbox instead of text
                'id'            => __('ID', 'taamul'),
                'user'          => __('User', 'taamul'),
                'page'          => __('Page', 'taamul'),
                'rating'        => __('Rating', 'taamul'),
                'message'       => __('Message', 'taamul'),
                'email'         => __('Email', 'taamul'),
                'device'        => __('Device', 'taamul'),
                'country'       => __('Country', 'taamul'),
                'browser'       => __('Browser', 'taamul'),
                'os'            => __('OS', 'taamul'),
                'date_time'     => __('Date', 'taamul'),
            );
            return $columns;
        }

        function get_sortable_columns(){
            $sortable_columns = array(
                'id' => array('id', true),
                'rating' => array('rating', false),
                'date_time' => array('date', false),
            );
            return $sortable_columns;
        }
    
        function get_bulk_actions(){
            $actions = array(
                'delete' => __('Delete', 'taamul'),
            );
            return $actions;
        }

        function process_bulk_action(){
            global $wpdb;
            $table_name = $wpdb->prefix . 'taamul'; // do not forget about tables prefix

            if ( 'delete' === $this->current_action() ) {
                if( isset($_REQUEST['id']) && is_array($_REQUEST['id']) ) {
                    $ids = isset($_REQUEST['id']) ? array_map( 'sanitize_text_field', $_REQUEST['id'] ) : array();
                }else{
                    $ids = isset( $_REQUEST['id'] ) ? sanitize_text_field( $_REQUEST['id'] ) : array();
                }

                if ( is_array( $ids ) ){
                    $ids = implode( ',', $ids );
                }
    
                if ( !empty( $ids ) ) {
                    $wpdb->query( "DELETE FROM $table_name WHERE id IN( $ids )" );
                }
            }
        }

        /**
         * Add Clear History button
         * 
         * @param [string] $which
         * @return void
         */
        public function extra_tablenav( $which ) {
            global $wpdb;

            if ( 'top' !== $which ) {
                return;
            }	
            $all_feedback_export_csv_args = array(
                'export_feedback_data' => 1,
                'export_feedback_type' => 'csv',
                'feedback_export_action' => 'export_all_csv_feedback',
            );

            $all_feedback_export_json_args = array(
                'export_feedback_data' => 1,
                'export_feedback_type' => 'json',
                'feedback_export_action' => 'export_all_json_feedback',
            );

            $table_name = $wpdb->prefix . 'taamul';
            $feedback_count = $wpdb->get_var( 'SELECT count(id) from '. $table_name );

            if( 1 <= $feedback_count ){

                $taamul_export_csv_nonce_url = esc_url( wp_nonce_url( add_query_arg( $all_feedback_export_csv_args, admin_url( 'admin.php' ) ), 'export_all_feedback_csv_nonce' ) );
                $taamul_export_json_nonce_url = esc_url( wp_nonce_url( add_query_arg( $all_feedback_export_json_args, admin_url( 'admin.php' ) ), 'export_all_feedback_json_nonce' ) );
                ?>
                <a class="button apply" href="<?php echo $taamul_export_csv_nonce_url; ?>">
                    <?php esc_html_e( 'Export all CSV', 'taamul' ); ?>
                </a>
                <a class="button apply" href="<?php echo $taamul_export_json_nonce_url; ?>">
                    <?php esc_html_e( 'Export all JSON', 'taamul' ); ?>
                </a>
                <?php

            }
        }
		
        function prepare_items(){
            global $wpdb;
            $table_name = $wpdb->prefix . 'taamul'; // do not forget about tables prefix
    
            $per_page = 10; // constant, how much records will be shown per page
            $columns = $this->get_columns();
            $hidden = array();
            $sortable = $this->get_sortable_columns();
    
           
            $this->_column_headers = array( $columns, $hidden, $sortable );
    
            $this->process_bulk_action();
    
            $total_items = $wpdb->get_var( "SELECT COUNT(id) FROM $table_name" );
    
            $paged = isset( ( $_REQUEST['paged'] ) ) ? ($per_page * max( 0, intval(sanitize_text_field( $_REQUEST['paged'] ) ) - 1 ) ) : 0;
            $orderby = ( isset( ( $_REQUEST['orderby'] ) ) && in_array( sanitize_text_field( $_REQUEST['orderby'] ), array_keys($this->get_sortable_columns() ) ) ) ? sanitize_text_field( $_REQUEST['orderby'] ) : 'id';
            $order = ( isset( ( $_REQUEST['order'] ) ) && in_array( sanitize_text_field( $_REQUEST['order'] ), array('asc', 'desc') ) ) ? sanitize_text_field( $_REQUEST['order'] ) : 'desc';
    
            $this->items = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM $table_name ORDER BY $orderby $order LIMIT %d OFFSET %d", $per_page, $paged ), ARRAY_A );
    
            for( $i = 0; $i < count( $this->items ); $i++ ){
                
                if( !empty( $this->items[$i]['country'] ) ){
                    $country = $this->items[$i]['country'];
                }else{
                    $country = "No Country Found";
                }

                $this->items[$i]['country'] = '<div class="taamul-tooltip"><img src="'. courtry_file_exist( $this->items[$i]['country_code'] ).'" alt="Coutry flag" style="width:25px;height:25px;border-radius: 100%;object-fit: cover;" ><span class="taamul-tooltiptext">'. $country .'</span></div>';
                $this->items[$i]['browser'] = '<div class="taamul-tooltip"><img src="'. browser_file_exist( $this->items[$i]['browser'] ).'" alt="Coutry flag" style="width:25px;height:25px;border-radius: 100%;object-fit: cover;" ><span class="taamul-tooltiptext">'. $this->items[$i]['browser'] .'</span></div>';
                $this->items[$i]['device']  = '<div class="taamul-tooltip"><img src="'. plugin_dir_url( __DIR__ ) .'img/dashboard/'.$this->items[$i]['device'].'.svg'.'" alt="Coutry flag" style="width:25px;height:25px;object-fit: cover;" ><span class="taamul-tooltiptext">'. $this->items[$i]['device'] .'</span></div>';
                $this->items[$i]['os']      = '<div class="taamul-tooltip"><img src="'. plugin_dir_url( __DIR__ ) .'img/os/'.$this->items[$i]['os'].'.svg'.'" alt="Coutry flag" style="width:25px;height:25px;object-fit: cover;" ><span class="taamul-tooltiptext">'. $this->items[$i]['os'] .'</span></div>';
                
                if( $this->items[$i]['page'] == 0 ){
                    $this->items[$i]['page'] = "<a href=".get_home_url().">".get_bloginfo( 'name' )."</a>";
                }else{
                    $this->items[$i]['page'] = "<a href=".get_permalink( $this->items[$i]['page'] ).">".get_the_title( $this->items[$i]['page'] )."</a>";
                }
            }

            $this->set_pagination_args( array(
                'total_items' => $total_items, // total items defined above
                'per_page' => $per_page, // per page constant defined at top of method
                'total_pages' => ceil( $total_items / $per_page ) // calculate pages count
            ) );
        }
}
