<?php

/**
 * Fired during plugin activation
 *
 * @link       https://taamul.com
 * @since      1.0.2
 *
 * @package    Taamul
 * @subpackage Taamul/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.2
 * @package    Taamul
 * @subpackage Taamul/includes
 * @author     Taamul <taamul.inc@gmail.com>
 */
class Taamul_Activator {

	/**
	 * Short Description. (use period)
	 *
	 * Long Description.
	 *
	 * @since    1.0.2
	 */
	public static function activate() {
		global $table_prefix, $wpdb;
		
		if( false === get_option( 'taamul_appearance_style', false ) ) {
			$taamul_options = array(
				'position_on_page' 	=> 'middlerightwithtext',
				'reactions_style' 	=> 'emoji1',
				'desktops' 			=> 'on',
				'tablets' 			=> 'on',
				'phones' 			=> 'on',
				'feedback_title' 	=> 'Give us Your Feedback',
				'message_form' 		=> 'Tell us about your experience...',
				'thank_you_message' => 'Thank you for your awesome review',
				'send_button' 		=> 'Send',
				'message' 			=> 'on',
				'message_required' 	=> 'on',
				'show_email' 		=> 'on',
				'email_required' 	=> 'on'
			);
	
			update_option( 'taamul_appearance_style', $taamul_options );
		}

		if( false === get_option( 'taamul_notification_setting', false ) ){
			$admin_email = get_option( 'admin_email', true );
			$taamul_notification_style = array(
				'email_recipient'   => $admin_email,
				'email_subject'     => 'New feedback submitted at '.get_bloginfo( 'name' ),
				'email_message'     => 'A new feedback has been submitted. View it: %link%. This email was sent from your website by the %plugin% plugin at %time%.',
			);
			update_option( 'taamul_notification_setting', $taamul_notification_style );
		}

		$table_name = $wpdb->prefix.'taamul';
		if( $wpdb->get_var( "show tables like '$table_name'" ) != $table_name ) {
			$sql = "CREATE TABLE $table_name (
				`id` int(11) NOT NULL AUTO_INCREMENT PRIMARY KEY,
				`user` varchar(255) NOT NULL,
				`page` varchar(255) NOT NULL,
				`rating` int(11) NOT NULL,
				`message` varchar(255) NOT NULL,
				`email` varchar(255) NOT NULL,
				`device` varchar(255) NOT NULL,
				`browser` varchar(255) NOT NULL,
				`os` varchar(255) NOT NULL,
				`country` varchar(255) DEFAULT NULL,
				`country_code` varchar(255) DEFAULT NULL,
				`ip_address` varchar(255) DEFAULT NULL,
				`date_time` datetime NOT NULL
			) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4";

			require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
			dbDelta($sql);
		}
	}

}
