<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://taamul.com
 * @since      1.0.4
 *
 * @package    Taamul
 * @subpackage Taamul/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Taamul
 * @subpackage Taamul/public
 * @author     Taamul <taamul.inc@gmail.com>
 */
class Taamul_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.4
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.4
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.4
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.4
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Taamul_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Taamul_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/taamul-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.4
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Taamul_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Taamul_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( 'taamul-add-typekit', plugin_dir_url( __FILE__ ) . 'js/taamul_modernizr.js', array(), '1.0' );
   		wp_add_inline_script( 'taamul-add-typekit', 'var Taamulfeedback = { ajaxurl: "'.admin_url ('admin-ajax.php').'" }' );
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/taamul_main.js', array( 'jquery' ), $this->version, false );
	}
	
	public function taamul_layout_asst() {	
		wp_enqueue_style( $this->plugin_name.'_taamul_reset', plugin_dir_url( __FILE__ ) . 'css/taamul_reset.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->plugin_name.'_taamul_style', plugin_dir_url( __FILE__ ) . 'css/taamul_style.css', array(), $this->version, 'all' );
		//wp_enqueue_script( $this->plugin_name.'_taamul_modernizr', plugin_dir_url( __FILE__ ) . 'js/taamul_modernizr.js', array( 'jquery' ), $this->version, false );
		
	}
	
	public function taamul_layout_display() {	
		require_once plugin_dir_path( __FILE__ ) . 'partials/view_feedback.php';
	}

	public function ajax_taamul(){
		global $wpdb;
		$table = $wpdb->prefix.'taamul';
		
		$user 				= isset( $_REQUEST['user'] ) ? sanitize_text_field($_REQUEST['user']) : '';
		$page 				= isset( $_REQUEST['page'] ) ? sanitize_text_field($_REQUEST['page']) : '';
		$rating 			= isset( $_REQUEST['rating'] ) ? sanitize_text_field($_REQUEST['rating']) : '';
		$message 			= isset( $_REQUEST['message'] ) ? sanitize_text_field($_REQUEST['message']) : '-';
		$email 				= isset( $_REQUEST['email'] ) ? sanitize_text_field($_REQUEST['email'] ) : '-';
		$device				= isset( $_REQUEST['device'] ) ? sanitize_text_field($_REQUEST['device'] ) : '';
		$browser 			= isset( $_REQUEST['browser'] ) ? sanitize_text_field($_REQUEST['browser'] ) : '';
		$os 				= isset( $_REQUEST['os'] ) ? sanitize_text_field($_REQUEST['os'] ) : '';
		$country 		    = isset( $_REQUEST['country'] ) ? sanitize_text_field($_REQUEST['country'] ) : '';
		$country_code       = isset( $_REQUEST['countrycode'] ) ? sanitize_text_field($_REQUEST['countrycode'] ) : '';
		$ip_address 		= isset( $_REQUEST['ipaddress'] ) ? sanitize_text_field($_REQUEST['ipaddress'] ) : '';
		$date_time			= current_time('mysql', 1);
		
		if (!filter_var( $email, FILTER_VALIDATE_EMAIL)) {
			$email = $email;
		}
	
		$data = array( 'user' => $user, 'page' => $page, 'rating' => $rating,'message' => $message,'email' => $email, 'device' => $device, 'browser' => $browser, 'os' => $os, 'country' => $country, 'country_code' => $country_code, 'ip_address' => $ip_address, 'date_time' => $date_time, );

		$format = array('%s','%s','%s','%s','%s','%s','%s','%s','%s','%s');
		$wpdb->insert($table,$data,$format);
		$tmids = $wpdb->insert_id;
		$from_mail = get_option('admin_email', true);
		$email_details  = get_option( 'taamul_notification_setting', true );
		$message        = str_replace('%link%', '<strong><a target="_blank" href="'.site_url( 'wp-admin/admin.php?page=taamul&tab=report' ).'">Click Here</a></strong>', $email_details['email_message'] );
		$message        = str_replace('%plugin%', '<strong>Taamul</strong>', $message );
		$message        = str_replace('%time%', date('d/m/Y h:i A'), $message );
		$message        = str_replace('%name%', $user, $message );
		$message        = str_replace('%email%', $email, $message );
		if( isset( $email_details ) && $email_details['show_email'] == 'on'){
			$to 		= explode(",",$email_details['email_recipient']);
			$subject 	= $email_details['email_subject'];
			$message  	= "<p>".$message."</p>";
			$headers[] 	= 'From:'. $from_mail ."\r\n";
			$headers[] 	= "MIME-Version: 1.0\r\n";
			$headers[] 	= "Content-type: text/html; charset=UTF-8";
			wp_mail( $to, $subject, $message, $headers );
		}
	
		return $tmids;
	}

}
