<?php

/**
 * Register all actions and filters for the plugin
 *
 * @link       https://taamul.com
 * @since      1.0.4
 *
 * @package    Taamul
 * @subpackage Taamul/includes
 */

/**
 * Register all actions and filters for the plugin.
 *
 * Maintain a list of all hooks that are registered throughout
 * the plugin, and register them with the WordPress API. Call the
 * run function to execute the list of actions and filters.
 *
 * @package    Taamul
 * @subpackage Taamul/includes
 * @author     Taamul <taamul.inc@gmail.com>
 */
class Taamul_Public_Common {

    /**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.4
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct() {

	}

    /**
     * Taamul Get Browsers name
     *
     * @return void
     */

    public function get_browser_name($user_agent){
		$t = strtolower($user_agent);
		$t = " " . $t;
		if     (strpos($t, 'opera'  ) || strpos($t, 'opr/')     ) return 'Opera';   
		elseif (strpos($t, 'edge'   )                           ) return 'Edge';   
		elseif (strpos($t, 'chrome' )                           ) return 'Chrome';   
		elseif (strpos($t, 'safari' )                           ) return 'Safari';   
		elseif (strpos($t, 'firefox')                           ) return 'Firefox';   
		elseif (strpos($t, 'msie'   ) || strpos($t, 'trident/7')) return 'Internet Explorer';
		return 'Unkown';
	}

    /**
     * Taamul Get operating_system
     *
     * @return void
     */

    public function get_taamul_operating_system() {
		$u_agent = $_SERVER['HTTP_USER_AGENT'];
		$operating_system = 'Unknown Operating System';
	
		//Get the operating_system name
		if (preg_match('/linux/i', $u_agent)) {
			$operating_system = 'Linux';
		} elseif (preg_match('/macintosh|mac os x|mac_powerpc/i', $u_agent)) {
			$operating_system = 'Mac';
		} elseif (preg_match('/windows|win32|win98|win95|win16/i', $u_agent)) {
			$operating_system = 'Windows';
		} elseif (preg_match('/ubuntu/i', $u_agent)) {
			$operating_system = 'Ubuntu';
		} elseif (preg_match('/iphone/i', $u_agent)) {
			$operating_system = 'IPhone';
		} elseif (preg_match('/ipod/i', $u_agent)) {
			$operating_system = 'IPod';
		} elseif (preg_match('/ipad/i', $u_agent)) {
			$operating_system = 'IPad';
		} elseif (preg_match('/android/i', $u_agent)) {
			$operating_system = 'Android';
		} elseif (preg_match('/blackberry/i', $u_agent)) {
			$operating_system = 'Blackberry';
		} elseif (preg_match('/webos/i', $u_agent)) {
			$operating_system = 'Mobile';
		}
		
		return $operating_system;
	}

    /**
     * Taamul Get login user username
     *
     * @return void
     */
    public function get_login_user_username(){
        if(!function_exists('wp_get_current_user')) {
            include(ABSPATH . "wp-includes/pluggable.php"); 
        }
        $current_user = wp_get_current_user();
        if( !empty( $current_user->data->ID ) ){
            return $current_user->data->user_login;
        }else{
            return "Unknown";
        }
    }

    /**
     * Taamul Get device
     *
     * @return void
     */
    public function get_feedback_device(){
        $is_mobile   = is_numeric(strpos(strtolower($_SERVER["HTTP_USER_AGENT"]), "mobile")); 
        $is_tablet   = is_numeric(strpos(strtolower($_SERVER["HTTP_USER_AGENT"]), "tablet"));
        $is_computer = is_numeric(strpos(strtolower($_SERVER["HTTP_USER_AGENT"]), "windows")); 
        
        if( $is_mobile ){ 
            if( $is_tablet ){ 
                $device = "Teblet"; 
            }else{ 
                $device = "Mobile";
            } 
        }else{ 
            $device = "Computer";
        }
        return $device;
    }

    /**
	 * Get user ip address to Country name.
	 *
	 * @since  1.0.4
	 * @return string
	 */
	public function ip_details( $ip_address ){
		$details = json_decode( file_get_contents( "http://www.geoplugin.net/json.gp?ip=" . $ip_address ) );
		return $details->geoplugin_countryName;
	}

    /**
	 * Get user ip address to Country name.
	 *
	 * @since  1.0.4
	 * @return string
	 */
	public function ip_details_country_code( $ip_address ){
		$details = json_decode( file_get_contents( "http://www.geoplugin.net/json.gp?ip=" . $ip_address ) );
		return $details->geoplugin_countryCode;
	}

	/**
	 * Get user ip address.
	 *
	 * @since  1.0.4
	 */
	public function getIPAddress() {  
		if(!empty( $_SERVER['HTTP_CLIENT_IP'] ) ) {  
			$ip = $_SERVER['HTTP_CLIENT_IP'];  
		}elseif ( !empty( $_SERVER['HTTP_X_FORWARDED_FOR'] ) ) {  
			$ip = $_SERVER['HTTP_X_FORWARDED_FOR'];  
		}else{  
			$ip = $_SERVER['REMOTE_ADDR'];  
		}
		return $ip;  
	}

    /**
     * Taamul Get feedback submit page
     *
     * @return void
     */
    public function get_feedback_submit_page(){
        if( is_home() === true ){
            $page_id = get_option('page_on_front');
        }else{
            $page_id = get_the_ID();
        }
        return $page_id;
    }

    /**
     * Taamul Display Feedback popup fucntion
     *
     * @return void
     */
    public function display_feedback_popup(){
        $get_appearance_style = get_option('taamul_appearance_style', true );
        $position_on_page 	= $get_appearance_style['position_on_page'];
        $thank_you_message  = !empty( $get_appearance_style['thank_you_message'] ) ? $get_appearance_style['thank_you_message'] : '';
        $message_required   = !empty( $get_appearance_style['message_required'] ) ? $get_appearance_style['message_required'] : '';
        $email_required     = !empty( $get_appearance_style['email_required'] ) ? $get_appearance_style['email_required'] : '';
        if ( !empty(  $position_on_page ) ) {
            switch (  $position_on_page ) {

                case 'middleright':
                    $position_on_page_class = 'taamul-popup-trigger-right';
                    $popup = 'taamul-popup-container-right';
                    $popup2 = 'taamul-popup-right';
                    $popup_trigger = 'taamul-popup-trigger';
                    $taamul_bottom = '';
                    $taamul_popup_trigger_tex = ' taamul-popup-trigger-icon taamul-desktop taamul-mobile';
                    break;

                case 'middleleft':
                    $position_on_page_class = 'taamul-popup-trigger-left';
                    $popup = 'taamul-popup-container-left';
                    $popup2 = 'taamul-popup-left';
                    $popup_trigger = 'taamul-popup-trigger';
                    $taamul_bottom = '';
                    $taamul_popup_trigger_tex = ' taamul-popup-trigger-icon taamul-desktop taamul-mobile';
                    break;

                case 'bottomright':
                    $position_on_page_class ='taamul-popup-trigger-bottom-right';
                    $popup = 'taamul-popup-container-bottom-right';
                    $popup2 = 'taamul-popup-bottom-right';
                    $popup_trigger = 'taamul-popup-trigger-bottom';
                    $taamul_bottom = 'taamul-bottom-right';
                    $taamul_popup_trigger_tex = ' taamul-popup-trigger-icon taamul-desktop taamul-mobile';
                    break;

                case 'bottomleft':
                    $position_on_page_class = 'taamul-popup-trigger-bottom-left';
                    $popup = 'taamul-popup-container-bottom-left';
                    $popup2 = 'taamul-popup-bottom-left';
                    $popup_trigger = 'taamul-popup-trigger-bottom';
                    $taamul_bottom = 'taamul-bottom-left';
                    $taamul_popup_trigger_tex = ' taamul-popup-trigger-icon taamul-desktop taamul-mobile';
                    break;

                case 'middlerightwithtext':
                    $position_on_page_class = 'taamul-popup-trigger-right';
                    $popup = 'taamul-popup-container-right';
                    $popup2 = 'taamul-popup-right';
                    $popup_trigger = 'taamul-popup-trigger';
                    $taamul_bottom = 'taamul-trigger-right';
                    $taamul_popup_trigger_tex = ' taamul-popup-trigger-text';
                    break;

                case 'middleleftwithtext':
                    $position_on_page_class = 'taamul-popup-trigger-left';
                    $popup = 'taamul-popup-container-left';
                    $popup2 = 'taamul-popup-left';
                    $popup_trigger = 'taamul-popup-trigger';
                    $taamul_bottom = 'taamul-trigger-left';
                    $taamul_popup_trigger_tex = ' taamul-popup-trigger-text';
                    break;

                case 'bottomrightwithtext':
                    $position_on_page_class = 'taamul-popup-trigger-bottom-right';
                    $popup = 'taamul-popup-container-bottom-right';
                    $popup2 = 'taamul-popup-bottom-right';
                    $popup_trigger = 'taamul-popup-trigger-bottom';
                    $taamul_bottom = 'taamul-trigger-bottom-right';
                    $taamul_popup_trigger_tex = ' taamul-popup-trigger-text';
                    break;

                case 'bottomleftwithtext':
                    $position_on_page_class = 'taamul-popup-trigger-bottom-left';
                    $popup = 'taamul-popup-container-bottom-left';
                    $popup2 = 'taamul-popup-bottom-left';
                    $popup_trigger = 'taamul-popup-trigger-bottom';
                    $taamul_bottom = 'taamul-trigger-bottom-left';
                    $taamul_popup_trigger_tex = ' taamul-popup-trigger-text';
                    break;

                default:
                    $position_on_page_class = 'taamul-popup-trigger-right';
                    $popup = 'taamul-popup-container-right';
                    $popup2 = 'taamul-popup-right';
                    $popup_trigger = 'taamul-popup-trigger';
                    $taamul_popup_trigger_tex = ' taamul-popup-trigger-icon taamul-desktop taamul-mobile';
                    break;
            }
        }
        ?>
        <a href="" class="taamul-popup-trigger">
            <div id="taamul" class="<?php echo $position_on_page_class,  $taamul_popup_trigger_tex; ?>">
                <div id="<?php echo $popup_trigger; ?>" class="<?php echo $taamul_bottom; ?>" ><?php if( $position_on_page == 'bottomrightwithtext' || $position_on_page == 'bottomleftwithtext' ){ echo _e('<span> Feedback </span>', 'taamul' );  }?>
                    <span>
                       <svg width="70" height="64" viewBox="0 0 70 64" fill="none" xmlns="http://www.w3.org/2000/svg">
<path d="M34.8192 0C15.728 0 0 14.541 0 32.1484C0 39.7651 2.86862 46.9861 8.11128 52.7233L0.791345 59.4498C0 60.1422 -0.197836 61.3292 0.197836 62.3184C0.593508 63.3076 1.58269 64 2.67079 64H34.8192C53.9104 64 69.4405 49.6569 69.4405 32.0495C69.4405 14.442 53.8114 0 34.8192 0ZM45.9969 16.3215C48.4699 16.3215 50.5471 18.2998 50.5471 20.8717C50.5471 23.3447 48.5688 25.4219 45.9969 25.4219C43.524 25.4219 41.4467 23.4436 41.4467 20.8717C41.4467 18.2998 43.425 16.3215 45.9969 16.3215ZM23.4436 16.3215C25.9165 16.3215 27.9938 18.2998 27.9938 20.8717C27.9938 23.3447 26.0155 25.4219 23.4436 25.4219C20.9706 25.4219 18.8934 23.4436 18.8934 20.8717C18.8934 18.2998 20.9706 16.3215 23.4436 16.3215ZM52.0309 36.5008C50.9428 43.1283 42.0402 47.7774 34.7202 47.7774C27.4003 47.7774 18.4977 43.1283 17.4096 36.5008C17.2117 35.1159 18.4977 33.9289 19.8825 34.3246C23.5425 35.5116 28.983 36.204 34.7202 36.204C40.4575 36.204 45.898 35.5116 49.558 34.3246C50.9428 33.9289 52.2287 35.1159 52.0309 36.5008Z" fill="white"/>
</svg>
                    </span><?php if( $position_on_page == 'middlerightwithtext' || $position_on_page == 'middleleftwithtext' ){ echo _e('<span> Feedback </span>', 'taamul' );  }?>
                </div>
            </div>
        </a>
        <div id="taamul">
            <div class="taamul-popup <?php echo $popup2; ?>" role="alert">
                <div class="taamul-popup-container <?php echo $popup; ?>">
                    <p class="taamul-title"><?php echo $get_appearance_style['feedback_title']; ?></p>
                    <ul class="taamul-buttons">
                    <li>
                        <a class="tm" href="#" onclick="displayboxtaxt('1')" ><img src="<?php echo plugin_dir_url( __FILE__ );?>img/01.svg" /></a>
                    </li>
                    <li>
                        <a class="tm" href="#" onclick="displayboxtaxt('2')"><img src="<?php echo plugin_dir_url( __FILE__ );?>img/02.svg" /></a>
                    </li>
                    <li>
                        <a class="tm" href="#" onclick="displayboxtaxt('3')"><img src="<?php echo plugin_dir_url( __FILE__ );?>img/03.svg" /></a>
                    </li>
                    <li>
                        <a class="tm" href="#" onclick="displayboxtaxt('4')"><img src="<?php echo plugin_dir_url( __FILE__ );?>img/04.svg" /></a>
                    </li>
                    <li>
                        <a class="tm" href="#" onclick="displayboxtaxt('5')"><img src="<?php echo plugin_dir_url( __FILE__ );?>img/05.svg" /></a>
                    </li>
                </ul>
                <div class="add_feed_back"></div>
                    <form class="taamul-form floating-labels taamul_fdiv">
                        <label class="taamul-label taamul_label" id="taamul_label_1" for="taamul-textarea"><?php esc_attr_e('Very Sad', 'taamul' ); ?></label>
                        <label class="taamul-label taamul_label" id="taamul_label_2" for="taamul-textarea"><?php esc_attr_e('Sad', 'taamul' ); ?></label>
                        <label class="taamul-label taamul_label" id="taamul_label_3" for="taamul-textarea"><?php esc_attr_e('Neutral', 'taamul' ); ?></label>
                        <label class="taamul-label taamul_label" id="taamul_label_4" for="taamul-textarea"><?php esc_attr_e('Happy', 'taamul' ); ?></label>
                        <label class="taamul-label taamul_label" id="taamul_label_5" for="taamul-textarea"><?php esc_attr_e('Very Happy', 'taamul' ); ?></label>
                        <input type="hidden" id="taamul_val" name="taamul_val" value="0">
                        <input type="hidden" id="taamul_page" name="taamul_page" value="<?php echo $this->get_feedback_submit_page();?>">
                        <span class="invalid_error" id="invalid_email" style="display:none; font-size:15px;color:#FF0000;"><?php esc_attr_e('Please enter a valid email address', 'taamul' ); ?></span>
                        <br><span class="invalid_error" id="invalid_message" style="display:none; font-size:15px; color:#FF0000;"><?php esc_attr_e('Please enter your experience', 'taamul' ); ?></span>
                        <?php
                            if( !empty( $get_appearance_style['show_email'] ) &&  $get_appearance_style['show_email'] == 'on' ){
                                ?>
                                <input type="email" name="user_email" id="user_email" placeholder="Enter your email" <?php if( !empty( $get_appearance_style['email_required'] ) &&  $get_appearance_style['email_required'] == 'on' ){ echo 'required="required"'; } ?> style="margin-top: 10px;" ><br>
                                <?php
                            }
                        ?>
                        <?php
                            if( !empty( $get_appearance_style['message'] ) &&  $get_appearance_style['message'] == 'on' ){
                                ?>
                                <textarea class="message" name="taamul-textarea" id="taamul-textarea" spellcheck="false" <?php if( !empty( $get_appearance_style['message_required'] ) &&  $get_appearance_style['message_required'] == 'on' ){ echo 'required="required"'; } ?> placeholder="<?php echo $get_appearance_style['message_form']; ?>"></textarea>
                                <?php
                            }
                        ?>
                        <div>
                            <input type="hidden" id="taamul_device" name="taamul_device" value="<?php echo $this->get_feedback_device();?>">
                            <input type="hidden" id="taamul_browser" name="taamul_browser" value="<?php echo $this->get_browser_name($_SERVER['HTTP_USER_AGENT']);?>">
                            <input type="hidden" id="taamul_os" name="taamul_os" value="<?php echo $this->get_taamul_operating_system();?>">
                            <input type="hidden" id="taamul_user" name="taamul_user" value="<?php echo $this->get_login_user_username();?>">
                            <input type="hidden" id="add_feed_back" value="<?php if( $thank_you_message ){ echo $thank_you_message; } ?>" >
                            <input type="hidden" id="mess_req" value="<?php if( $message_required ){ echo $message_required; } ?>" >
                            <input type="hidden" id="email_req" value="<?php if( $email_required ){ echo $email_required; } ?>" >
                            <?php $ip_address  = $this->getIPAddress(); ?> 
                            <input type="hidden" id="country" value="<?php echo $this->ip_details( $ip_address ); ?>" >
                            <input type="hidden" id="country_code" value="<?php echo $this->ip_details_country_code( $ip_address ); ?>" >
                            <input type="hidden" id="ip_address" value="<?php echo $ip_address; ?>" >
                            <input type="button" id="taamul_submit" value="<?php echo $get_appearance_style['send_button']; ?>" />
                        </div>
                    </form> 
                    <a href="#" class="taamul-popup-close img-replace"><?php esc_attr_e('Close', 'taamul' ); ?></a>
                    <div class="taamul-poweredby">
                        <a href="https://taamul.com" target="_blank" data-tooltip="Powered by Taamul" class="taamul-poweredby-tooltip">
                            <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 40 40">
                                <path d="M.84,35.53a1.51,1.51,0,0,0,1,2.61H20.05c10.81,0,19.6-8.11,19.6-18.09S30.86,1.86,20.05,1.86.35,10.08.35,20.05A17.16,17.16,0,0,0,5,31.7ZM11,23.07" transform="translate(-0.35 -1.86)" fill="#a5b2bd"></path>
                                <path d="M28.42,21.33a29.73,29.73,0,0,1-8.42,1,29.65,29.65,0,0,1-8.41-1,1.1,1.1,0,0,0-1.42,1.22c.63,3.75,5.69,6.37,9.83,6.37s9.19-2.62,9.83-6.37a1.1,1.1,0,0,0-1.41-1.22Z" transform="translate(-0.35 -1.86)" fill="#ffffff"></path>
                                <circle cx="13.27" cy="11.77" r="2.55" fill="#ffffff"></circle>
                                <circle cx="26.02" cy="11.77" r="2.55" fill="#ffffff"></circle>
                            </svg>
                        </a>
                    </div>
                </div>
            </div>
        </div>
    <?php 
    }
}